# qutebrowser quickstart

The Compiler
`<mail@qutebrowser.org>`

Note | This page will only appear on the first start. To view it at a later time, use the `:help` command.

## What to do now

- View the keybinding cheatsheet to make yourself familiar with the keybindings:

- If you just cloned the repository, you’ll need to run `scripts/asciidoc2html.py` to generate the documentation.

- Subscribe to the mailinglist where there are weekly "what’s new in qutebrowser" posts.

- Let me know what features you are missing or things that need (even small!) improvements.

## Getting help

If you get stuck, you can get help in multiple ways:

- The `:help` command inside qutebrowser shows the built-in documentation. Additionally, each command can be started with a `--help` flag to show its help.

- IRC channel: `#qutebrowser` on Freenode (webchat)

- Mailinglist: qutebrowser@lists.qutebrowser.org ( subscribe)

## Donating

Working on qutebrowser is a very rewarding hobby, but like (nearly) all hobbies it also costs some money. Namely I have to pay for the server and domain, and do occasional hardware upgrades
[It turned out a 160 GB SSD is rather small - the VMs and custom Qt builds I use for testing/developing qutebrowser need about 100 GB of space]
.

If you want to give me a beer or a pizza back, I’m trying to make it as easy as possible for you to do so. If some other way would be easier for you, please get in touch!

- PayPal: me@the-compiler.org

- Bitcoin: 1PMzbcetAHfpxoXww8Bj5XqquHtVvMjJtE